# [djangorestframework-mvt](https://corteva.github.io/djangorestframework-mvt)

A Django REST Framework extension for creating views that serialize model data to Google Protobuf encoded Map Box Vector Tiles via Postgres.

[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![Build Status](https://travis-ci.org/corteva/djangorestframework-mvt.svg?branch=master)](https://travis-ci.org/corteva/djangorestframework-mvt)
[![PyPI version](https://badge.fury.io/py/djangorestframework-mvt.svg)](https://badge.fury.io/py/djangorestframework-mvt)
[![Coverage Status](https://coveralls.io/repos/github/corteva/djangorestframework-mvt/badge.svg?branch=master)](https://coveralls.io/github/corteva/djangorestframework-mvt?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)


## Documentation

https://corteva.github.io/djangorestframework-mvt
